Installation
************

From PyPI
=========

1. Run::

    $ pip install message-ix-models


From source
===========

1. Clone the code.
2. Run [1]_::

    $ pip install --no-use-pep517 --editable .

.. [1] See `pypa/pip#7953 <https://github.com/pypa/pip/issues/7953#issuecomment-676600130>`_.
